# configs (for developers)

Repository for storing all settings.

How to use:

Create new setting

- create new setting schema in *settings/schemas.py* or use existing one
- create new setting in *settings/all_settings.py* (*SETTINGS*) by next pattern:
    
```python
    'NEW_SETTING_NAME': BaseSettingDefinition(
        settingName='NEW_SETTING_NAME',         # setting name here
           services=[LUNA_FACES],                  # list of services which can use this setting
            schema={
            "type": "object", 
               "properties":[{
                "seting_key": {
                    "type": "string",
                    "enum":["value"]
                }
            }], 
            "required": ["key"], 
            "additionalProperties": False
        },                                      # validation schema for new setting
        default={"seting_key": "value"},        # default value for setting
        description="description"),             # new setting description
```

* Setting name MUST be `UPPER_SNAKE_CASE`.
* Setting properties' names MUST be `lower_snake_case`.


# configs migration generation (for developers)

* make required changes to `all_settings.py` and/or `schemas.py`

* generate migration by running command `python -m configs.generate <MIGRATION_NAME>`

* check the generated migration and, if necessary, make changes (for example, additional functions for changing settings values in the database), 
see *versions/examples* for more information

* the generated migration and updated settings dump (`actual_dump.json`) should be added to VCS

* if conflicts arise, manually specify `DOWN_REVISION` for conflicting migration (requires only one head migration), 
than specify a new head revision to *version* of *actual_dump.json*

# configs migration (for users&developers)

* check `configs/migration/config.conf` configuration

* to run migration execute one of the following commands

    * `python -m configs.migrate head` - to migrate to the latest migration revision

    * `python -m configs.migrate -1` - to migrate to previous revision

    * `python -m configs.migrate <VERSION>` - to migration to specified <VERISION> revision

    * `python -m configs.migrate null` - full downgrade (including remove component from migration table)
    
* migration results will be present in log files, if any errors occurred throw migration, it will not be applied,
  during migration, the database will be available only for reading
