"""
Configs migration

Generation datetime: 2020-11-17 09:12:41.312759
"""

from configs_core.migration.db_migrate_helper import DatabaseMigrationHelper as mh

REVISION = "869f0c13"
DOWN_REVISION = "base_revision"


def upgrade():
    """Upgrade configs to new revision"""

    # groups to add
    mh.addGroup(groupName="luna-api sdk settings", groupDescription="")
    mh.addGroup(groupName="luna-queue", groupDescription="")
    mh.addGroup(groupName="luna-platform", groupDescription="")

    # limitations to add
    mh.addLimitation(
        limitationName="ADDITIONAL_SERVICES_USAGE",
        validationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "indexed_matcher": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "liveness": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "indexed_matcher",
                "luna_matcher_proxy",
                "liveness",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        defaultValue={
            "luna_sender": False,
            "luna_events": False,
            "luna_tasks": False,
            "indexed_matcher": False,
            "luna_matcher_proxy": False,
            "liveness": False,
        },
        description="whether to use nested optional services",
        services=[
            "luna-admin",
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="ATTRIBUTES_STORAGE_POLICY",
        validationSchema={
            "type": "object",
            "properties": {
                "default_ttl": {"type": "integer", "minimum": 0},
                "max_ttl": {"type": "integer", "minimum": 0},
            },
            "description": "temporary attributes storage settings",
            "additionalProperties": False,
        },
        defaultValue={"default_ttl": 300, "max_ttl": 86400},
        description="temporary attributes storage settings",
        services=["luna-backport4", "luna-faces"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="BODY_DETECTOR",
        validationSchema={
            "type": "object",
            "properties": {
                "image_size": {"type": "integer", "minimum": 1},
                "redetect_score_threshold": {"type": "number"},
                "score_threshold": {"type": "number"},
                "landmarks17_threshold": {"type": "number"},
            },
            "description": "settings for human body detector",
            "additionalProperties": False,
        },
        defaultValue={
            "image_size": 640,
            "redetect_score_threshold": 0.12,
            "score_threshold": 0.3,
            "landmarks17_threshold": 0.25,
        },
        description="body detector settings",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="CLUSTERING_MATCH_LIMIT",
        validationSchema={"type": "integer"},
        defaultValue=5,
        description="Candidates count limit in match response",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="CRAWLER_PERIOD",
        validationSchema={"type": "number"},
        defaultValue=1,
        description="luna-faces polling frequency, in minutes",
        services=["luna-index-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="DATABASE_NUMBER",
        validationSchema={"type": "integer", "enum": [0, 1, 2]},
        defaultValue=0,
        description="database number (if 1 or 2), 0 - use one database",
        services=["luna-faces"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="DEFAULT_FACE_DESCRIPTOR_VERSION",
        validationSchema={"type": "integer"},
        defaultValue=59,  # hack for migration with empty tables
        description="default face descriptor version to work with",
        services=[
            "luna-api",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
        ],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="DEFAULT_HUMAN_DESCRIPTOR_VERSION",
        validationSchema={"type": "integer"},
        defaultValue=101,
        description="default human descriptor version to work with",
        services=[
            "luna-events",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
        ],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="DEFAULT_IMAGE_EXTENSION",
        validationSchema={"type": "string", "enum": ["jpg", "png"]},
        defaultValue="jpg",
        description="default image extension for image storing",
        services=["luna-image-store"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="DESCRIPTORS_CACHE",
        validationSchema={
            "type": "object",
            "properties": {
                "cache_enabled": {"type": "boolean"},
                "updating_cache_interval": {"type": "number", "exclusiveMinimum": 0},
                "matching_settings": {
                    "type": "object",
                    "properties": {"thread_count": {"type": "integer", "minimum": 0}},
                    "description": "matcher lib settings",
                    "additionalProperties": False,
                },
            },
            "description": "python matcher descriptor caching settings",
            "additionalProperties": False,
        },
        defaultValue={
            "cache_enabled": True,
            "updating_cache_interval": 2,
            "matching_settings": {"thread_count": 0},
        },
        description="LUNA Python Matcher descriptor caching settings",
        services=["luna-python-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="EVENTS_DATABASE",
        validationSchema={
            "type": "object",
            "properties": {
                "database": {
                    "type": "object",
                    "properties": {
                        "driver": {"type": "string"},
                        "config": {
                            "type": "object",
                            "properties": {
                                "dbName": {"type": "string"},
                                "host": {"type": "string"},
                                "port": {"type": "integer"},
                                "user": {"type": "string"},
                                "password": {"type": "string"},
                                "friendTag": {"type": "string"},
                                "strangerTag": {"type": "string"},
                                "eventDataToSkip": {
                                    "type": "array",
                                    "items": {"type": "string", "enum": ["location"]},
                                },
                                "eventDataOptional": {
                                    "type": "array",
                                    "items": {
                                        "type": "string",
                                        "enum": ["is_friend", "age", "sex"],
                                    },
                                },
                            },
                        },
                    },
                    "required": ["driver"],
                    "additionalProperties": False,
                }
            },
            "description": "Events database settings.",
            "additionalProperties": False,
        },
        defaultValue={
            "database": {
                "driver": "dbpostgresdrv",
                "config": {
                    "dbName": "luna_events",
                    "host": "127.0.0.1",
                    "user": "luna",
                    "port": 5432,
                    "friendTag": "1",
                    "strangerTag": "0",
                    "eventDataToSkip": ["location"],
                },
            }
        },
        description="Events matcher settings.",
        services=["luna-indexed-matcher", "luna-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="FACE_DETECTOR_V1",
        validationSchema={
            "type": "object",
            "properties": {
                "min_face_size": {"type": "integer", "minimum": 1},
                "scale_factor": {"type": "number"},
                "use_lnet": {"type": "boolean"},
            },
            "description": "settings for face detector version 1 and 2",
            "additionalProperties": False,
        },
        defaultValue={"min_face_size": 50, "scale_factor": 0.7, "use_lnet": True},
        description="face detector version 1 settings",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="FACE_DETECTOR_V2",
        validationSchema={
            "type": "object",
            "properties": {
                "min_face_size": {"type": "integer", "minimum": 1},
                "scale_factor": {"type": "number"},
                "use_lnet": {"type": "boolean"},
            },
            "description": "settings for face detector version 1 and 2",
            "additionalProperties": False,
        },
        defaultValue={"min_face_size": 50, "scale_factor": 0.7, "use_lnet": True},
        description="face detector version 2 settings",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="FACE_DETECTOR_V3",
        validationSchema={
            "type": "object",
            "properties": {
                "min_face_size": {"type": "integer", "minimum": 1},
                "max_face_size": {"type": "integer", "minimum": 1},
                "redetect_tensor_size": {"type": "integer", "minimum": 1},
                "redetect_face_target_size": {"type": "integer", "minimum": 1},
                "redetect_score_threshold": {"type": "number"},
                "score_threshold": {"type": "number"},
                "use_orientation_mode": {"type": "boolean"},
            },
            "description": "settings for face detector version 3",
            "additionalProperties": False,
        },
        defaultValue={
            "max_face_size": 640,
            "min_face_size": 50,
            "redetect_tensor_size": 80,
            "redetect_face_target_size": 45,
            "redetect_score_threshold": 0.357,
            "score_threshold": 0.89,
            "use_orientation_mode": False,
        },
        description="face detector version 3 settings",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="FETCH_EXTERNAL_IMAGE_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 10,
            "connect": 10,
            "sock_connect": 10,
            "sock_read": 10,
        },
        description="timeouts for http-request to external resource for fetch image",
        services=["luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INDEXED_FACES_LISTS",
        validationSchema={"type": "array", "items": {"type": "string"}, "minItems": 0},
        defaultValue=[],
        description="lists for indexation, for value ['all'] will be indexed all lists with attributes count > MIN_FACES_IN_LIST_FOR_INDEXING",
        services=["luna-index-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INDEXED_LISTS_REFRESH_RATE",
        validationSchema={"type": "integer"},
        defaultValue=1,
        description="indexed lists refresh rate, in seconds, works if USE_INDEX_MANAGER",
        services=["luna-matcher-proxy"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INDEXED_MATCHER_FACES_CLIENT_PROPERTIES",
        validationSchema={
            "type": "object",
            "properties": {
                "httpClient": {
                    "type": "object",
                    "properties": {
                        "requestTimeoutMs": {"type": "integer"},
                        "connectTimeoutMs": {"type": "integer"},
                    },
                    "description": "Timeouts settings.",
                }
            },
        },
        defaultValue={"httpClient": {"requestTimeoutMs": 5000, "connectTimeoutMs": 2000}},
        description="Indexed matcher faces client properties.",
        services=["luna-indexed-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INDEXED_MATCHER_FSDK",
        validationSchema={
            "type": "object",
            "properties": {
                "fsdk": {
                    "type": "object",
                    "properties": {
                        "configPath": {"type": "string"},
                        "runtimeConfigPath": {"type": "string"},
                        "dataPath": {"type": "string"},
                    },
                    "description": "Paths to fsdk config and data.",
                }
            },
        },
        defaultValue={
            "fsdk": {
                "configPath": "/srv/luna/conf/faceengine.conf",
                "runtimeConfigPath": "/srv/luna/conf/runtime.conf",
                "dataPath": "/srv/luna/data",
            }
        },
        description="Indexed matcher fsdk settings.",
        services=["luna-indexed-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INDEXED_MATCHER_QUEUE",
        validationSchema={
            "type": "object",
            "properties": {
                "routing_key": {"type": "string"},
                "rabbit_exchange": {"type": "string"},
            },
            "required": ["routing_key"],
            "additionalProperties": False,
        },
        defaultValue={
            "routing_key": "indexed_matcher",
            "rabbit_exchange": "luna.match",
        },
        description="Indexed Matcher queue settings.",
        services=["luna-admin", "luna-indexed-matcher"],
        groupNames=["luna-platform", "luna-queue"],
    )
    mh.addLimitation(
        limitationName="INDEXED_MATCHER_WORKER_AND_MESSAGE",
        validationSchema={
            "type": "object",
            "properties": {
                "msg": {"type": "object", "properties": {"path": {"type": "string"}}},
                "worker": {
                    "type": "object",
                    "properties": {
                        "connection": {
                            "type": "object",
                            "properties": {
                                "enableDLQ": {"type": "boolean"},
                                "qos": {"type": "integer"},
                                "disableAck": {"type": "boolean"},
                                "produceOnly": {"type": "boolean"},
                            },
                        }
                    },
                },
            },
            "description": "Worker and messaging settings.",
        },
        defaultValue={
            "msg": {"path": ""},
            "worker": {
                "connection": {
                    "enableDLQ": False,
                    "qos": 1,
                    "disableAck": False,
                    "produceOnly": False,
                }
            },
        },
        description="Indexed matcher worker and messaging settings.",
        services=["luna-indexed-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INDEXED_MATCHING",
        validationSchema={
            "type": "object",
            "properties": {
                "cache": {
                    "type": "object",
                    "properties": {
                        "capacity": {"type": "integer"},
                        "policy": {"type": "string", "enum": ["classic", "warmup"]},
                        "skipList": {"type": "array", "items": {"type": "string"}},
                    },
                },
                "listsLoadExternalIds": {"type": "boolean"},
                "matcherStrategy": {
                    "type": "string",
                    "enum": ["lists", "indexes", "events"],
                },
                "staticBatchCapacity": {"type": "integer"},
                "staticBatchVersionCheckPeriod": {"type": "integer"},
                "matchingThreadCheckPeriodCoeff": {"type": "number"},
                "warmupPreloadPerPageRetries": {"type": "integer"},
                "lists_data_source": {"type": "string", "enum": ["rawfaces_api"]},
                "ef_search": {"type": "integer"},
                "goldengate_support": {"type": "boolean"},
                "onReload": {
                    "type": "object",
                    "properties": {
                        "logging": {
                            "type": "object",
                            "properties": {
                                "log-to-stderr": {"type": "boolean"},
                                "log-also-to-stderr": {"type": "boolean"},
                                "log-verbosity": {"type": "integer"},
                                "log-min-level": {"type": "integer"},
                                "log-buf-sec": {"type": "integer"},
                                "log-buf-level": {"type": "integer"},
                            },
                        }
                    },
                },
                "eventsInsertTimeDeltaHandicapSeconds": {
                    "type": "integer",
                    "minimum": 0,
                },
            },
            "description": "Matcher settings.",
        },
        defaultValue={
            "matcherStrategy": "indexes",
            "staticBatchCapacity": 5000,
            "staticBatchVersionCheckPeriod": 500,
            "lists_data_source": "rawfaces_api",
            "ef_search": 1600,
            "goldengate_support": False,
            "onReload": {
                "logging": {
                    "log-to-stderr": False,
                    "log-also-to-stderr": True,
                    "log-verbosity": 2,
                    "log-min-level": 0,
                    "log-buf-sec": 30,
                    "log-buf-level": 0,
                }
            },
        },
        description="Matcher settings.",
        services=["luna-indexed-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INDEXER_FACES_CLIENT_PROPERTIES",
        validationSchema={
            "type": "object",
            "properties": {
                "httpClient": {
                    "type": "object",
                    "properties": {
                        "requestTimeoutMs": {"type": "integer"},
                        "connectTimeoutMs": {"type": "integer"},
                    },
                    "description": "Timeouts settings.",
                }
            },
        },
        defaultValue={"httpClient": {"requestTimeoutMs": 5000, "connectTimeoutMs": 2000}},
        description="Indexer faces client properties.",
        services=["luna-indexer"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INDEXER_FSDK",
        validationSchema={
            "type": "object",
            "properties": {
                "fsdk": {
                    "type": "object",
                    "properties": {
                        "configPath": {"type": "string"},
                        "runtimeConfigPath": {"type": "string"},
                        "dataPath": {"type": "string"},
                    },
                    "description": "Paths to fsdk config and data.",
                }
            },
        },
        defaultValue={
            "fsdk": {
                "configPath": "/srv/luna/conf/faceengine.conf",
                "runtimeConfigPath": "/srv/luna/conf/runtime.conf",
                "dataPath": "/srv/luna/data",
            }
        },
        description="Indexer fsdk settings.",
        services=["luna-indexer"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INDEXER_QUEUE",
        validationSchema={
            "type": "object",
            "properties": {
                "routing_key": {"type": "string"},
                "rabbit_exchange": {"type": "string"},
            },
            "required": ["routing_key"],
            "additionalProperties": False,
        },
        defaultValue={"routing_key": "indexer", "rabbit_exchange": "luna.index"},
        description="Indexer queue settings.",
        services=["luna-admin", "luna-index-manager", "luna-indexer"],
        groupNames=["luna-platform", "luna-queue"],
    )
    mh.addLimitation(
        limitationName="INDEXER_WORKER_AND_MESSAGE",
        validationSchema={
            "type": "object",
            "properties": {
                "msg": {"type": "object", "properties": {"path": {"type": "string"}}},
                "worker": {
                    "type": "object",
                    "properties": {
                        "connection": {
                            "type": "object",
                            "properties": {
                                "enableDLQ": {"type": "boolean"},
                                "qos": {"type": "integer"},
                                "disableAck": {"type": "boolean"},
                                "produceOnly": {"type": "boolean"},
                            },
                        }
                    },
                },
            },
            "description": "Worker and messaging settings.",
        },
        defaultValue={
            "msg": {"path": ""},
            "worker": {
                "connection": {
                    "enableDLQ": False,
                    "qos": 1,
                    "disableAck": False,
                    "produceOnly": False,
                }
            },
        },
        description="Indexer worker and messaging settings",
        services=["luna-indexer"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INDEXING",
        validationSchema={
            "type": "object",
            "properties": {
                "index": {
                    "type": "object",
                    "properties": {
                        "indexPeriodHrs": {"type": "integer"},
                        "concurrentFetch": {"type": "boolean"},
                        "store_index_max_days": {"type": "integer"},
                        "ef_construction": {"type": "integer"},
                    },
                    "description": "Indexer settings.",
                }
            },
            "required": ["index"],
        },
        defaultValue={
            "index": {
                "indexPeriodHrs": -1,
                "concurrentFetch": True,
                "store_index_max_days": -1,
                "ef_construction": 1600,
            }
        },
        description="Indexer settings.",
        services=["luna-indexer"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INDEX_PATH",
        validationSchema={
            "type": "object",
            "properties": {"indexPath": {"type": "string"}},
            "required": ["indexPath"],
            "description": "The path to which the constructed indices will be stored.",
        },
        defaultValue={"indexPath": "/var/lib/luna/index"},
        description="The path to which the constructed indices will be stored.",
        services=["luna-indexer"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INDEX_RELOADED_FOLDER",
        validationSchema={
            "type": "object",
            "properties": {"indices_folder": {"type": "string"}},
            "required": ["indices_folder"],
            "description": "The path to the directory where the indices are located.",
        },
        defaultValue={"indices_folder": "/dev/shm/index_reload"},
        description="The path to the directory where the indices are located.",
        services=["luna-indexed-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="INFLUX_MONITORING",
        validationSchema={
            "properties": {
                "send_data_for_monitoring": {"type": "integer", "enum": [0, 1]},
                "use_ssl": {"type": "integer", "enum": [0, 1]},
                "flushing_period": {"type": "number"},
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "database_name": {"type": "string"},
                "user_name": {"type": "string"},
                "password": {"type": "string"},
            },
            "required": ["send_data_for_monitoring", "host", "port", "database_name"],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "send_data_for_monitoring": 0,
            "use_ssl": 0,
            "flushing_period": 1,
            "host": "127.0.0.1",
            "port": 8086,
            "database_name": "luna_monitoring",
            "user_name": "luna",
            "password": "luna",
        },
        description="monitoring parameters",
        services=[
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-configurator",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-index-manager",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-sender",
            "luna-tasks",
        ],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LIVENESS_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                }
            },
            "required": ["origin"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://localhost:8080"},
        description="Http settings for liveness",
        services=["luna-admin", "luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LIVENESS_PREDICTION_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 20,
        },
        description="timeouts for liveness service",
        services=["luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LIVENESS_THRESHOLD",
        validationSchema={"type": "number", "exclusiveMinimum": 0},
        defaultValue=0.5,
        description="Threshold for the likelihood that a person is alive",
        services=["luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LOCAL_STORAGE",
        validationSchema={"type": "string"},
        defaultValue="./local_storage",
        description="directory for images storing",
        services=["luna-image-store"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_ADMIN_DB",
        validationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_admin",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        description="Main database for luna-admin service",
        services=["luna-admin"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_ADMIN_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Admin logger settings",
        services=["luna-admin"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_ADMIN_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to other services from luna-admin",
        services=["luna-admin"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_API_ACTIVE_PLUGINS",
        validationSchema={"type": "array", "items": {"type": "string"}},
        defaultValue=[],
        description="list active plugins",
        services=["luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_API_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5000", "api_version": 6},
        description="LUNA API address",
        services=["luna-admin", "luna-backport3", "luna-backport4"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_API_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Api logger settings",
        services=["luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_API_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-api service",
        services=["luna-backport3", "luna-backport4"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_ATTRIBUTES_DB",
        validationSchema={
            "type": "object",
            "properties": {
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "password": {"type": "string"},
                "channel": {"type": "string"},
                "sentinel": {
                    "description": "Redis sentinels settings",
                    "type": "object",
                    "properties": {
                        "master_name": {"type": "string"},
                        "sentinels": {
                            "type": "array",
                            "items": {
                                "description": "Redis sentinel settings. Host+port",
                                "type": "string",
                                "pattern": "[a-zA-Z0-9.]+:\\d{1,5}",
                                "example": "127.0.0.1:26379",
                            },
                        },
                    },
                    "additionalProperties": False,
                    "required": ["master_name", "sentinels"],
                },
                "number": {
                    "type": "integer",
                    "enum": [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14],
                },
            },
            "additionalProperties": False,
        },
        defaultValue={
            "host": "127.0.0.1",
            "port": 6379,
            "password": "",
            "channel": "luna-sender",
            "sentinel": {"master_name": "luna_attributes", "sentinels": []},
            "number": 0,
        },
        description="luna temporary attributes database address",
        services=["luna-faces", "luna-matcher-proxy", "luna-python-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_BACKPORT3_ACTIVE_PLUGINS",
        validationSchema={"type": "array", "items": {"type": "string"}},
        defaultValue=[],
        description="list active plugins",
        services=["luna-backport3"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_BACKPORT3_DB",
        validationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_backport3",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        description="Main database for luna-backport3 service",
        services=["luna-backport3"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_BACKPORT3_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Backport3 logger settings",
        services=["luna-backport3"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_BACKPORT4_ACTIVE_PLUGINS",
        validationSchema={"type": "array", "items": {"type": "string"}},
        defaultValue=[],
        description="list active plugins",
        services=["luna-backport4"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_BACKPORT4_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Backport4 logger settings",
        services=["luna-backport4"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_CONFIGURATOR",
        validationSchema={
            "type": "object",
            "properties": {
                "use_configurator": {"type": "boolean"},
                "luna_configurator_origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "luna_configurator_api": {"type": "integer"},
            },
            "description": "whether to get configs from configurator and its origin and api",
            "required": ["use_configurator"],
            "additionalProperties": False,
        },
        defaultValue={
            "use_configurator": False,
            "luna_configurator_origin": "http://127.0.0.1:5070",
            "luna_configurator_api": 1,
        },
        description="whether to get configs from configurator and its origin and api",
        services=[
            "luna-admin",
            "luna-api",
            "luna-backport3",
            "luna-backport4",
            "luna-configurator",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-image-store",
            "luna-index-manager",
            "luna-licenses",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-sender",
            "luna-tasks",
        ],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_CONFIGURATOR_DB",
        validationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_configurator",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        description="Main database for luna-configurator service",
        services=["luna-configurator"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_CONFIGURATOR_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Configurator logger settings",
        services=["luna-configurator"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_EVENTS_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5040", "api_version": 2},
        description="LUNA Events address",
        services=["luna-admin", "luna-api", "luna-handlers", "luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_EVENTS_DB",
        validationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "db_type": "vertica",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_events",
            "db_host": "127.0.0.1",
            "db_port": 5433,
        },
        description="Main database for luna-events service",
        services=["luna-events", "luna-matcher-proxy", "luna-python-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_EVENTS_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Events logger settings",
        services=["luna-events"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_EVENTS_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-events service",
        services=["luna-api", "luna-handlers", "luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_FACES_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5030", "api_version": 3},
        description="LUNA Faces address",
        services=[
            "luna-admin",
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-index-manager",
            "luna-indexed-matcher",
            "luna-indexer",
            "luna-licenses",
            "luna-matcher",
            "luna-tasks",
        ],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_FACES_DB",
        validationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_faces",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        description="Main database for luna-faces service",
        services=["luna-faces", "luna-matcher-proxy", "luna-python-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_FACES_DB_PING_MAX_COUNT",
        validationSchema={"type": "integer"},
        defaultValue=0,
        description="max count of database ping tries (<= 0 without ping)",
        services=["luna-faces"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_FACES_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Faces logger settings",
        services=["luna-faces"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_FACES_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-faces service",
        services=[
            "luna-api",
            "luna-backport4",
            "luna-handlers",
            "luna-index-manager",
            "luna-licenses",
            "luna-tasks",
        ],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_ACTIVE_PLUGINS",
        validationSchema={"type": "array", "items": {"type": "string"}},
        defaultValue=[],
        description="list active plugins",
        services=["luna-handlers"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5090", "api_version": 1},
        description="LUNA Handlers address",
        services=["luna-admin", "luna-api", "luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_DB",
        validationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_handlers",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        description="Main database for luna-api service",
        services=["luna-handlers"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_DETECTOR_RUNTIME_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "device_class": {"type": "string", "enum": ["cpu", "gpu"]},
                "num_threads": {"type": "integer", "minimum": 1},
                "num_compute_streams": {"type": "integer", "minimum": 1},
            },
            "description": "sdk runtime settings",
            "additionalProperties": False,
        },
        defaultValue={
            "device_class": "cpu",
            "num_threads": 4,
            "num_compute_streams": 4,
        },
        description="runtime settings for face detector in handlers",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_DETECTOR_TYPE",
        validationSchema={
            "type": "string",
            "enum": ["FACE_DET_V1", "FACE_DET_V2", "FACE_DET_V3"],
        },
        defaultValue="FACE_DET_V3",
        description="luna-handlers face detector type",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_DETECT_FACES_STAGE_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "optimal_batch_size": {"type": "integer", "minimum": 1},
                "worker_count": {"type": "integer", "minimum": 1},
            },
            "description": "settings for handlers stage",
            "additionalProperties": False,
        },
        defaultValue={"optimal_batch_size": 8, "worker_count": 1},
        description="luna-handlers detect faces stage settings",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_DETECT_HUMANS_STAGE_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "optimal_batch_size": {"type": "integer", "minimum": 1},
                "worker_count": {"type": "integer", "minimum": 1},
            },
            "description": "settings for handlers stage",
            "additionalProperties": False,
        },
        defaultValue={"optimal_batch_size": 8, "worker_count": 1},
        description="luna-handlers detect humans stage settings",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_EXTRACTOR_RUNTIME_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "device_class": {"type": "string", "enum": ["cpu", "gpu"]},
                "num_threads": {"type": "integer", "minimum": 1},
                "num_compute_streams": {"type": "integer", "minimum": 1},
            },
            "description": "sdk runtime settings",
            "additionalProperties": False,
        },
        defaultValue={
            "device_class": "cpu",
            "num_threads": 4,
            "num_compute_streams": 4,
        },
        description="runtime settings for face extractor in handlers",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_EXTRACT_STAGE_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "optimal_batch_size": {"type": "integer", "minimum": 1},
                "worker_count": {"type": "integer", "minimum": 1},
            },
            "description": "settings for handlers stage",
            "additionalProperties": False,
        },
        defaultValue={"optimal_batch_size": 13, "worker_count": 1},
        description="luna-handlers face extract stage settings",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_HUMAN_DETECTOR_RUNTIME_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "device_class": {"type": "string", "enum": ["cpu", "gpu"]},
                "num_threads": {"type": "integer", "minimum": 1},
                "num_compute_streams": {"type": "integer", "minimum": 1},
            },
            "description": "sdk runtime settings",
            "additionalProperties": False,
        },
        defaultValue={
            "device_class": "cpu",
            "num_threads": 4,
            "num_compute_streams": 4,
        },
        description="runtime settings for human detector in handlers",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_HUMAN_EXTRACTOR_RUNTIME_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "device_class": {"type": "string", "enum": ["cpu", "gpu"]},
                "num_threads": {"type": "integer", "minimum": 1},
                "num_compute_streams": {"type": "integer", "minimum": 1},
            },
            "description": "sdk runtime settings",
            "additionalProperties": False,
        },
        defaultValue={
            "device_class": "cpu",
            "num_threads": 4,
            "num_compute_streams": 4,
        },
        description="runtime settings for human extractor in handlers",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_HUMAN_EXTRACT_STAGE_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "optimal_batch_size": {"type": "integer", "minimum": 1},
                "worker_count": {"type": "integer", "minimum": 1},
            },
            "description": "settings for handlers stage",
            "additionalProperties": False,
        },
        defaultValue={"optimal_batch_size": 13, "worker_count": 1},
        description="luna-handlers human extract stage settings",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_LOAD_EXTERNAL_IMAGES_TIMEOUT",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 10,
            "connect": 10,
            "sock_connect": 10,
            "sock_read": 10,
        },
        description="timeouts for http-request to external resource for download images",
        services=["luna-handlers"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Handlers logger settings",
        services=["luna-handlers"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-handlers service",
        services=["luna-api", "luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_WARP_ESTIMATE_STAGE_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "optimal_batch_size": {"type": "integer", "minimum": 1},
                "worker_count": {"type": "integer", "minimum": 1},
            },
            "description": "settings for handlers stage",
            "additionalProperties": False,
        },
        defaultValue={"optimal_batch_size": 1, "worker_count": 1},
        description="luna-handlers face warp estimation stage settings",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_WARP_ESTIMATOR_RUNTIME_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "device_class": {"type": "string", "enum": ["cpu", "gpu"]},
                "num_threads": {"type": "integer", "minimum": 1},
                "num_compute_streams": {"type": "integer", "minimum": 1},
            },
            "description": "sdk runtime settings",
            "additionalProperties": False,
        },
        defaultValue={
            "device_class": "cpu",
            "num_threads": 4,
            "num_compute_streams": 4,
        },
        description="runtime settings for face warp estimator in handlers",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-api sdk settings"],
    )
    mh.addLimitation(
        limitationName="LUNA_IMAGE_STORE_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Image Store logger settings",
        services=["luna-image-store"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_IMAGE_STORE_PORTRAITS_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        defaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "portraits",
        },
        description="Address of service for storing task results",
        services=["luna-backport3"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_IMAGE_STORE_PORTRAITS_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-image-store service",
        services=["luna-backport3"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_IMAGE_STORE_SAMPLES_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        defaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "visionlabs-samples",
        },
        description="Address of service for storing samples",
        services=["luna-admin", "luna-api", "luna-handlers", "luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_IMAGE_STORE_SAMPLES_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-image-store service",
        services=["luna-api", "luna-handlers", "luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_IMAGE_STORE_TASK_RESULT_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": ["origin", "api_version", "bucket"],
            "additionalProperties": False,
        },
        defaultValue={
            "origin": "http://127.0.0.1:5020",
            "api_version": 1,
            "bucket": "task-result",
        },
        description="Address of service for storing task results",
        services=["luna-admin", "luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_IMAGE_STORE_TASK_RESULT_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-image-store service",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_INDEX_MANAGER_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5060", "api_version": 1},
        description="LUNA Index Manager address",
        services=["luna-admin", "luna-matcher-proxy"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_INDEX_MANAGER_DB",
        validationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_index_manager",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        description="Main database for luna-index-manager service",
        services=["luna-index-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_INDEX_MANAGER_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Index Manager logger settings",
        services=["luna-index-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_INDEX_MANAGER_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-index-manager service",
        services=["luna-matcher-proxy"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LICENSES_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5120", "api_version": 1},
        description="LUNA Licenses address",
        services=["luna-admin", "luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_LICENSES_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Licenses logger settings",
        services=["luna-licenses"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_MATCHERS_DAEMONS_ORIGINS",
        validationSchema={
            "type": "array",
            "items": {"type": "string"},
            "minItems": 1,
            "description": "Matcher daemon endpoints.",
        },
        defaultValue=["http://127.0.0.1:6000/1"],
        description="list of luna-matcher-daemon endpoints",
        services=["luna-index-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_MATCHER_CLUSTERS",
        validationSchema={
            "type": "array",
            "description": "luna matcher clusters",
            "items": {
                "type": "object",
                "description": "core matcher cluster",
                "properties": {
                    "routing_key": {"type": "string"},
                    "rabbit_exchange": {"type": "string"},
                    "cluster_type": {
                        "type": "string",
                        "enum": ["core-matcher", "core-indexed-matcher"],
                    },
                },
                "required": ["routing_key", "cluster_type"],
                "additionalProperties": False,
                "default": {
                    "cluster_type": "python-matcher",
                    "routing_key": "matcher",
                    "rabbit_exchange": "luna.match",
                },
            },
            "minItems": 0,
        },
        defaultValue=[
            {
                "cluster_type": "core-matcher",
                "routing_key": "matcher",
                "rabbit_exchange": "luna.match",
            }
        ],
        description="LUNA Matcher cluster list",
        services=["luna-matcher-proxy"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_MATCHER_DAEMON_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-matcher-daemon service",
        services=["luna-index-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_MATCHER_PROXY_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5110", "api_version": 1},
        description="LUNA Python Matcher Proxy address",
        services=["luna-admin", "luna-api", "luna-handlers", "luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_MATCHER_PROXY_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Matcher Proxy logger settings",
        services=["luna-matcher-proxy"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_PROXY_TO_PYTHON_MATCHER_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 300,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 300,
        },
        description="timeouts for http-request from luna-python-matcher-proxy to luna-python-matcher service",
        services=["luna-matcher-proxy"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_PYTHON_MATCHER_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5100", "api_version": 1},
        description="LUNA Python Matcher address",
        services=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-tasks",
        ],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_PYTHON_MATCHER_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Python Matcher logger settings",
        services=["luna-python-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_PYTHON_MATCHER_PROXY_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-matcher-proxy service",
        services=["luna-api", "luna-handlers"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_PYTHON_MATCHER_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-python-matcher service",
        services=["luna-api", "luna-handlers"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_SENDER_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5080", "api_version": 2},
        description="LUNA Sender address",
        services=["luna-admin", "luna-backport4"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_SENDER_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Sender logger settings",
        services=["luna-sender"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_TASKS_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5050", "api_version": 2},
        description="LUNA Tasks address",
        services=["luna-admin", "luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_TASKS_DB",
        validationSchema={
            "properties": {
                "db_type": {
                    "type": "string",
                    "enum": ["postgres", "oracle", "vertica"],
                },
                "db_user": {"type": "string"},
                "db_password": {"type": "string"},
                "db_name": {"type": "string"},
                "db_host": {"type": "string"},
                "db_port": {"type": "integer", "minimum": 1, "maximum": 65535},
            },
            "required": [
                "db_type",
                "db_user",
                "db_password",
                "db_name",
                "db_host",
                "db_port",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "db_type": "postgres",
            "db_user": "luna",
            "db_password": "luna",
            "db_name": "luna_tasks",
            "db_host": "127.0.0.1",
            "db_port": 5432,
        },
        description="Main database for luna-tasks service",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_TASKS_LOGGER",
        validationSchema={
            "type": "object",
            "properties": {
                "log_level": {
                    "type": "string",
                    "enum": ["ERROR", "WARNING", "INFO", "DEBUG"],
                },
                "folder_with_logs": {"type": "string"},
                "max_log_file_size": {"type": "integer"},
                "log_time": {"type": "string", "enum": ["LOCAL", "UTC"]},
                "log_to_stdout": {"type": "boolean"},
                "log_to_file": {"type": "boolean"},
                "multiline_stack_trace": {"type": "boolean"},
            },
            "additionalProperties": False,
        },
        defaultValue={
            "log_level": "INFO",
            "folder_with_logs": "./",
            "max_log_file_size": 1024,
            "log_time": "LOCAL",
            "log_to_stdout": True,
            "log_to_file": True,
            "multiline_stack_trace": True,
        },
        description="Luna Tasks logger settings",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_TASKS_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        description="timeouts for http-request to luna-tasks service",
        services=["luna-api"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_TASKS_TO_MATCHER_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 300,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 300,
        },
        description="timeouts for http-request to LUNA Matcher entry point service",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_TASKS_WORKER_ADDRESS",
        validationSchema={
            "type": "string",
            "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
            "example": "http://127.0.0.1:5051",
        },
        defaultValue="http://127.0.0.1:5051",
        description="Luna Tasks Worker address",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_TASKS_WORKER_TIMEOUTS",
        validationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        defaultValue={
            "request": 600,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 600,
        },
        description="timeouts for http-request to luna-tasks-worker service",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="MATCHER_FACES_CLIENT_PROPERTIES",
        validationSchema={
            "type": "object",
            "properties": {
                "httpClient": {
                    "type": "object",
                    "properties": {
                        "requestTimeoutMs": {"type": "integer"},
                        "connectTimeoutMs": {"type": "integer"},
                    },
                    "description": "Timeouts settings.",
                }
            },
        },
        defaultValue={"httpClient": {"requestTimeoutMs": 5000, "connectTimeoutMs": 2000}},
        description="Matcher faces client properties.",
        services=["luna-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="MATCHER_FSDK",
        validationSchema={
            "type": "object",
            "properties": {
                "fsdk": {
                    "type": "object",
                    "properties": {
                        "configPath": {"type": "string"},
                        "runtimeConfigPath": {"type": "string"},
                        "dataPath": {"type": "string"},
                    },
                    "description": "Paths to fsdk config and data.",
                }
            },
        },
        defaultValue={
            "fsdk": {
                "configPath": "/srv/luna/conf/faceengine.conf",
                "runtimeConfigPath": "/srv/luna/conf/runtime.conf",
                "dataPath": "/srv/luna/data",
            }
        },
        description="Matcher fsdk settings.",
        services=["luna-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="MATCHER_QUEUE",
        validationSchema={
            "type": "object",
            "properties": {
                "routing_key": {"type": "string"},
                "rabbit_exchange": {"type": "string"},
            },
            "required": ["routing_key"],
            "additionalProperties": False,
        },
        defaultValue={"routing_key": "matcher", "rabbit_exchange": "luna.match"},
        description="Matcher queue settings.",
        services=["luna-admin", "luna-matcher"],
        groupNames=["luna-platform", "luna-queue"],
    )
    mh.addLimitation(
        limitationName="MATCHER_WORKER_AND_MESSAGE",
        validationSchema={
            "type": "object",
            "properties": {
                "msg": {"type": "object", "properties": {"path": {"type": "string"}}},
                "worker": {
                    "type": "object",
                    "properties": {
                        "connection": {
                            "type": "object",
                            "properties": {
                                "enableDLQ": {"type": "boolean"},
                                "qos": {"type": "integer"},
                                "disableAck": {"type": "boolean"},
                                "produceOnly": {"type": "boolean"},
                            },
                        }
                    },
                },
            },
            "description": "Worker and messaging settings.",
        },
        defaultValue={
            "msg": {"path": ""},
            "worker": {
                "connection": {
                    "enableDLQ": False,
                    "qos": 1,
                    "disableAck": False,
                    "produceOnly": False,
                }
            },
        },
        description="Matcher worker and messaging settings.",
        services=["luna-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="MATCHING",
        validationSchema={
            "type": "object",
            "properties": {
                "cache": {
                    "type": "object",
                    "properties": {
                        "capacity": {"type": "integer"},
                        "policy": {"type": "string", "enum": ["classic", "warmup"]},
                        "skipList": {"type": "array", "items": {"type": "string"}},
                    },
                },
                "listsLoadExternalIds": {"type": "boolean"},
                "matcherStrategy": {
                    "type": "string",
                    "enum": ["lists", "indexes", "events"],
                },
                "staticBatchCapacity": {"type": "integer"},
                "staticBatchVersionCheckPeriod": {"type": "integer"},
                "matchingThreadCheckPeriodCoeff": {"type": "number"},
                "warmupPreloadPerPageRetries": {"type": "integer"},
                "lists_data_source": {"type": "string", "enum": ["rawfaces_api"]},
                "ef_search": {"type": "integer"},
                "goldengate_support": {"type": "boolean"},
                "onReload": {
                    "type": "object",
                    "properties": {
                        "logging": {
                            "type": "object",
                            "properties": {
                                "log-to-stderr": {"type": "boolean"},
                                "log-also-to-stderr": {"type": "boolean"},
                                "log-verbosity": {"type": "integer"},
                                "log-min-level": {"type": "integer"},
                                "log-buf-sec": {"type": "integer"},
                                "log-buf-level": {"type": "integer"},
                            },
                        }
                    },
                },
                "eventsInsertTimeDeltaHandicapSeconds": {
                    "type": "integer",
                    "minimum": 0,
                },
            },
            "description": "Matcher settings.",
        },
        defaultValue={
            "cache": {"capacity": 1500, "policy": "classic"},
            "matcherStrategy": "lists",
            "staticBatchCapacity": 5000,
            "staticBatchVersionCheckPeriod": 500,
            "matchingThreadCheckPeriodCoeff": 2.5,
            "warmupPreloadPerPageRetries": 5,
            "lists_data_source": "rawfaces_api",
            "goldengate_support": False,
            "onReload": {
                "logging": {
                    "log-to-stderr": False,
                    "log-also-to-stderr": True,
                    "log-verbosity": 2,
                    "log-min-level": 0,
                    "log-buf-sec": 30,
                    "log-buf-level": 0,
                }
            },
        },
        description="Matcher settings.",
        services=["luna-matcher"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="MAX_CANDIDATE_IN_RESPONSE",
        validationSchema={"type": "integer", "minimum": 1},
        defaultValue=5,
        description="max candidate count into a response on matching request",
        services=["luna-backport3"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="MAX_ERROR_COUNT_PER_TASK",
        validationSchema={"type": "integer"},
        defaultValue=100000,
        description="Maximum errors count per task to store",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="MIN_FACES_IN_LIST_FOR_INDEXING",
        validationSchema={"type": "integer"},
        defaultValue=50000,
        description="min face count in list for indexing",
        services=["luna-index-manager"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="QUEUE_SETTINGS",
        validationSchema={
            "type": "object",
            "description": "Core queue connection settings.",
            "oneOf": [
                {
                    "description": "Core Rabbit MQ settings.",
                    "type": "object",
                    "properties": {
                        "queue_type": {"type": "string", "enum": ["rabbit"]},
                        "max_retries": {"type": "integer"},
                        "delay_step": {"type": "integer"},
                        "api_version": {"type": "integer"},
                        "request_timeout": {"type": "number", "exclusiveMinimum": 0},
                        "host": {"type": "string"},
                        "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                        "user": {"type": "string"},
                        "password": {"type": "string"},
                    },
                    "required": [
                        "queue_type",
                        "api_version",
                        "host",
                        "port",
                        "user",
                        "password",
                    ],
                    "additionalProperties": False,
                    "default": {
                        "queue_type": "rabbit",
                        "max_retries": 5,
                        "delay_step": 10,
                        "request_timeout": 30,
                        "api_version": 14,
                        "host": "127.0.0.1",
                        "port": 5672,
                        "user": "luna",
                        "password": "luna",
                    },
                },
                {
                    "description": "Core IBM MQ settings.",
                    "type": "object",
                    "properties": {
                        "queue_type": {"type": "string", "enum": ["ibmmq"]},
                        "max_retries": {"type": "integer"},
                        "delay_step": {"type": "integer"},
                        "api_version": {"type": "integer"},
                        "request_timeout": {"type": "number", "exclusiveMinimum": 0},
                        "host": {"type": "string"},
                        "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                        "user": {"type": "string"},
                        "password": {"type": "string"},
                        "ibm_manager": {"type": "string"},
                        "ibm_channel": {"type": "string"},
                        "ibm_template": {"type": "string"},
                        "ibm_heart_beat_interval": {"type": "integer"},
                    },
                    "required": [
                        "queue_type",
                        "api_version",
                        "host",
                        "port",
                        "user",
                        "password",
                        "ibm_manager",
                        "ibm_channel",
                        "ibm_heart_beat_interval",
                        "ibm_template",
                    ],
                    "additionalProperties": False,
                    "default": {
                        "max_retries": 5,
                        "api_version": 14,
                        "queue_type": "ibmmq",
                        "host": "127.0.0.1",
                        "port": 1414,
                        "user": "luna",
                        "password": "luna",
                        "ibm_manager": "SATURN.QUEUE.MANAGER",
                        "ibm_channel": "PASSWORD.SVRCONN",
                        "ibm_template": "SYSTEM.DEFAULT.MODEL.QUEUE",
                        "ibm_heart_beat_interval": 1,
                    },
                },
                {
                    "description": "Core SQS settings.",
                    "type": "object",
                    "properties": {
                        "queue_type": {"type": "string", "enum": ["sqs"]},
                        "max_retries": {"type": "integer"},
                        "delay_step": {"type": "integer"},
                        "api_version": {"type": "integer"},
                        "request_timeout": {"type": "number", "exclusiveMinimum": 0},
                        "aws_public_access_key": {"type": "string"},
                        "aws_secret_access_key": {"type": "string"},
                        "aws_scheme": {
                            "type": "string",
                            "enum": ["http", "https", "MQTT"],
                        },
                        "aws_authorization_signature": {
                            "type": "string",
                            "enum": ["s3v2", "s3v4"],
                        },
                        "aws_region": {"type": "string"},
                        "aws_connect_timeout": {"type": "integer"},
                    },
                    "required": [
                        "queue_type",
                        "api_version",
                        "aws_public_access_key",
                        "aws_secret_access_key",
                        "aws_authorization_signature",
                    ],
                    "additionalProperties": False,
                    "default": {
                        "queue_type": "sqs",
                        "api_version": 1,
                        "aws_public_access_key": "",
                        "aws_secret_access_key": "",
                        "aws_scheme": "https",
                        "aws_authorization_signature": "s3v4",
                        "aws_region": "",
                        "aws_connect_timeout": 20,
                    },
                },
            ],
        },
        defaultValue={
            "queue_type": "rabbit",
            "max_retries": 5,
            "delay_step": 10,
            "request_timeout": 30,
            "api_version": 14,
            "host": "127.0.0.1",
            "port": 5672,
            "user": "luna",
            "password": "luna",
        },
        description="Determines queue connection settings.",
        services=[
            "luna-admin",
            "luna-index-manager",
            "luna-indexed-matcher",
            "luna-indexer",
            "luna-matcher",
            "luna-matcher-proxy",
        ],
        groupNames=["luna-platform", "luna-queue"],
    )
    mh.addLimitation(
        limitationName="REDIS_DB_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "host": {"type": "string"},
                "port": {"type": "integer", "minimum": 1, "maximum": 65535},
                "password": {"type": "string"},
                "channel": {"type": "string"},
                "sentinel": {
                    "description": "Redis sentinels settings",
                    "type": "object",
                    "properties": {
                        "master_name": {"type": "string"},
                        "sentinels": {
                            "type": "array",
                            "items": {
                                "description": "Redis sentinel settings. Host+port",
                                "type": "string",
                                "pattern": "[a-zA-Z0-9.]+:\\d{1,5}",
                                "example": "127.0.0.1:26379",
                            },
                        },
                    },
                    "additionalProperties": False,
                    "required": ["master_name", "sentinels"],
                },
            },
            "additionalProperties": False,
        },
        defaultValue={
            "host": "127.0.0.1",
            "port": 6379,
            "password": "",
            "channel": "luna-sender",
            "sentinel": {"master_name": "luna_sender_master", "sentinels": []},
        },
        description="Redis database address",
        services=["luna-handlers", "luna-sender"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="S3",
        validationSchema={
            "properties": {
                "host": {"type": "string"},
                "region": {"type": "string"},
                "aws_public_access_key": {"type": "string"},
                "aws_secret_access_key": {"type": "string"},
                "authorization_signature": {"type": "string", "enum": ["s3v2", "s3v4"]},
                "request_timeout": {"type": "integer"},
                "connect_timeout": {"type": "integer"},
                "bucket": {"type": "string"},
            },
            "required": [
                "host",
                "aws_public_access_key",
                "aws_secret_access_key",
                "authorization_signature",
            ],
            "type": "object",
            "additionalProperties": False,
        },
        defaultValue={
            "host": "http://localhost:7480",
            "region": "",
            "aws_public_access_key": "",
            "aws_secret_access_key": "",
            "authorization_signature": "s3v4",
            "request_timeout": 60,
            "connect_timeout": 30,
            "bucket": "lis_bucket",
        },
        description="AWS S3 settings",
        services=["luna-image-store"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="SAVE_EVENTS_INTERVAL",
        validationSchema={"type": "integer"},
        defaultValue=1,
        description="Interval for 'copy' events into db, in seconds",
        services=["luna-events"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="SAVE_EVENTS_TIMEOUT",
        validationSchema={"type": "number"},
        defaultValue=2,
        description="save events timeout. 0 or negative means no timeout",
        services=["luna-events"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="STORAGE_TIME",
        validationSchema={"type": "string", "enum": ["LOCAL", "UTC"]},
        defaultValue="LOCAL",
        description="Time in which records are stored in the database",
        services=[
            "luna-backport3",
            "luna-configurator",
            "luna-events",
            "luna-faces",
            "luna-handlers",
            "luna-index-manager",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-tasks",
        ],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="STORAGE_TYPE",
        validationSchema={"type": "string", "enum": ["LOCAL", "S3"]},
        defaultValue="LOCAL",
        description="Storage type. LOCAL - local directory, S3 - AWS S3",
        services=["luna-image-store"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="TASKS_ROUTER_TO_WORKER_REQUESTS_CONCURRENCY",
        validationSchema={"type": "integer"},
        defaultValue=10,
        description="Concurrency for sending subtasks to luna-tasks-workers",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="TASKS_TO_FACES_REQUESTS_CONCURRENCY",
        validationSchema={"type": "integer"},
        defaultValue=5,
        description="Concurrency for requests to luna-faces",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="TASKS_TO_HANDLERS_CONCURRENCY",
        validationSchema={"type": "integer", "minimum": 0},
        defaultValue=8,
        description="Tasks to handlers extract request concurrency.",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="TASKS_TO_IMAGE_STORE_REQUESTS_CONCURRENCY",
        validationSchema={"type": "integer"},
        defaultValue=100,
        description="Concurrency for requests to luna-image-store",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="USE_MATERIAL_VIEWS",
        validationSchema={"type": "integer", "enum": [0, 1]},
        defaultValue=0,
        description="Use materialized views flag",
        services=["luna-faces"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="USE_SAMPLES_AS_PORTRAITS",
        validationSchema={"type": "boolean"},
        defaultValue=True,
        description="use samples as portraits",
        services=["luna-backport3"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="WORKERS_COUNT_PER_TASK_TYPE",
        validationSchema={"type": "integer"},
        defaultValue=5,
        description="Workers' concurrency: number of workers for every task type",
        services=["luna-tasks"],
        groupNames=["luna-platform"],
    )


def downgrade():
    """Downgrade configs to previous revision"""

    # groups to remove
    mh.removeGroup(groupName="luna-api sdk settings")
    mh.removeGroup(groupName="luna-queue")
    mh.removeGroup(groupName="luna-platform")

    # limitations to remove
    mh.removeLimitation(limitationName="ADDITIONAL_SERVICES_USAGE")
    mh.removeLimitation(limitationName="ATTRIBUTES_STORAGE_POLICY")
    mh.removeLimitation(limitationName="BODY_DETECTOR")
    mh.removeLimitation(limitationName="CLUSTERING_MATCH_LIMIT")
    mh.removeLimitation(limitationName="CRAWLER_PERIOD")
    mh.removeLimitation(limitationName="DATABASE_NUMBER")
    mh.removeLimitation(limitationName="DEFAULT_FACE_DESCRIPTOR_VERSION")
    mh.removeLimitation(limitationName="DEFAULT_HUMAN_DESCRIPTOR_VERSION")
    mh.removeLimitation(limitationName="DEFAULT_IMAGE_EXTENSION")
    mh.removeLimitation(limitationName="DESCRIPTORS_CACHE")
    mh.removeLimitation(limitationName="EVENTS_DATABASE")
    mh.removeLimitation(limitationName="FACE_DETECTOR_V1")
    mh.removeLimitation(limitationName="FACE_DETECTOR_V2")
    mh.removeLimitation(limitationName="FACE_DETECTOR_V3")
    mh.removeLimitation(limitationName="FETCH_EXTERNAL_IMAGE_TIMEOUTS")
    mh.removeLimitation(limitationName="INDEXED_FACES_LISTS")
    mh.removeLimitation(limitationName="INDEXED_LISTS_REFRESH_RATE")
    mh.removeLimitation(limitationName="INDEXED_MATCHER_FACES_CLIENT_PROPERTIES")
    mh.removeLimitation(limitationName="INDEXED_MATCHER_FSDK")
    mh.removeLimitation(limitationName="INDEXED_MATCHER_QUEUE")
    mh.removeLimitation(limitationName="INDEXED_MATCHER_WORKER_AND_MESSAGE")
    mh.removeLimitation(limitationName="INDEXED_MATCHING")
    mh.removeLimitation(limitationName="INDEXER_FACES_CLIENT_PROPERTIES")
    mh.removeLimitation(limitationName="INDEXER_FSDK")
    mh.removeLimitation(limitationName="INDEXER_QUEUE")
    mh.removeLimitation(limitationName="INDEXER_WORKER_AND_MESSAGE")
    mh.removeLimitation(limitationName="INDEXING")
    mh.removeLimitation(limitationName="INDEX_PATH")
    mh.removeLimitation(limitationName="INDEX_RELOADED_FOLDER")
    mh.removeLimitation(limitationName="INFLUX_MONITORING")
    mh.removeLimitation(limitationName="LIVENESS_ADDRESS")
    mh.removeLimitation(limitationName="LIVENESS_PREDICTION_TIMEOUTS")
    mh.removeLimitation(limitationName="LIVENESS_THRESHOLD")
    mh.removeLimitation(limitationName="LOCAL_STORAGE")
    mh.removeLimitation(limitationName="LUNA_ADMIN_DB")
    mh.removeLimitation(limitationName="LUNA_ADMIN_LOGGER")
    mh.removeLimitation(limitationName="LUNA_ADMIN_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_API_ACTIVE_PLUGINS")
    mh.removeLimitation(limitationName="LUNA_API_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_API_LOGGER")
    mh.removeLimitation(limitationName="LUNA_API_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_ATTRIBUTES_DB")
    mh.removeLimitation(limitationName="LUNA_BACKPORT3_ACTIVE_PLUGINS")
    mh.removeLimitation(limitationName="LUNA_BACKPORT3_DB")
    mh.removeLimitation(limitationName="LUNA_BACKPORT3_LOGGER")
    mh.removeLimitation(limitationName="LUNA_BACKPORT4_ACTIVE_PLUGINS")
    mh.removeLimitation(limitationName="LUNA_BACKPORT4_LOGGER")
    mh.removeLimitation(limitationName="LUNA_CONFIGURATOR")
    mh.removeLimitation(limitationName="LUNA_CONFIGURATOR_DB")
    mh.removeLimitation(limitationName="LUNA_CONFIGURATOR_LOGGER")
    mh.removeLimitation(limitationName="LUNA_EVENTS_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_EVENTS_DB")
    mh.removeLimitation(limitationName="LUNA_EVENTS_LOGGER")
    mh.removeLimitation(limitationName="LUNA_EVENTS_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_FACES_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_FACES_DB")
    mh.removeLimitation(limitationName="LUNA_FACES_DB_PING_MAX_COUNT")
    mh.removeLimitation(limitationName="LUNA_FACES_LOGGER")
    mh.removeLimitation(limitationName="LUNA_FACES_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_ACTIVE_PLUGINS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_DB")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_DETECTOR_RUNTIME_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_DETECTOR_TYPE")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_DETECT_FACES_STAGE_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_DETECT_HUMANS_STAGE_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_EXTRACTOR_RUNTIME_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_EXTRACT_STAGE_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_HUMAN_DETECTOR_RUNTIME_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_HUMAN_EXTRACTOR_RUNTIME_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_HUMAN_EXTRACT_STAGE_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_LOAD_EXTERNAL_IMAGES_TIMEOUT")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_LOGGER")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_WARP_ESTIMATE_STAGE_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_HANDLERS_WARP_ESTIMATOR_RUNTIME_SETTINGS")
    mh.removeLimitation(limitationName="LUNA_IMAGE_STORE_LOGGER")
    mh.removeLimitation(limitationName="LUNA_IMAGE_STORE_PORTRAITS_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_IMAGE_STORE_PORTRAITS_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_IMAGE_STORE_SAMPLES_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_IMAGE_STORE_SAMPLES_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_IMAGE_STORE_TASK_RESULT_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_IMAGE_STORE_TASK_RESULT_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_INDEX_MANAGER_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_INDEX_MANAGER_DB")
    mh.removeLimitation(limitationName="LUNA_INDEX_MANAGER_LOGGER")
    mh.removeLimitation(limitationName="LUNA_INDEX_MANAGER_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_LICENSES_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_LICENSES_LOGGER")
    mh.removeLimitation(limitationName="LUNA_MATCHERS_DAEMONS_ORIGINS")
    mh.removeLimitation(limitationName="LUNA_MATCHER_CLUSTERS")
    mh.removeLimitation(limitationName="LUNA_MATCHER_DAEMON_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_MATCHER_PROXY_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_MATCHER_PROXY_LOGGER")
    mh.removeLimitation(limitationName="LUNA_PROXY_TO_PYTHON_MATCHER_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_PYTHON_MATCHER_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_PYTHON_MATCHER_LOGGER")
    mh.removeLimitation(limitationName="LUNA_PYTHON_MATCHER_PROXY_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_PYTHON_MATCHER_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_SENDER_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_SENDER_LOGGER")
    mh.removeLimitation(limitationName="LUNA_TASKS_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_TASKS_DB")
    mh.removeLimitation(limitationName="LUNA_TASKS_LOGGER")
    mh.removeLimitation(limitationName="LUNA_TASKS_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_TASKS_TO_MATCHER_TIMEOUTS")
    mh.removeLimitation(limitationName="LUNA_TASKS_WORKER_ADDRESS")
    mh.removeLimitation(limitationName="LUNA_TASKS_WORKER_TIMEOUTS")
    mh.removeLimitation(limitationName="MATCHER_FACES_CLIENT_PROPERTIES")
    mh.removeLimitation(limitationName="MATCHER_FSDK")
    mh.removeLimitation(limitationName="MATCHER_QUEUE")
    mh.removeLimitation(limitationName="MATCHER_WORKER_AND_MESSAGE")
    mh.removeLimitation(limitationName="MATCHING")
    mh.removeLimitation(limitationName="MAX_CANDIDATE_IN_RESPONSE")
    mh.removeLimitation(limitationName="MAX_ERROR_COUNT_PER_TASK")
    mh.removeLimitation(limitationName="MIN_FACES_IN_LIST_FOR_INDEXING")
    mh.removeLimitation(limitationName="QUEUE_SETTINGS")
    mh.removeLimitation(limitationName="REDIS_DB_ADDRESS")
    mh.removeLimitation(limitationName="S3")
    mh.removeLimitation(limitationName="SAVE_EVENTS_INTERVAL")
    mh.removeLimitation(limitationName="SAVE_EVENTS_TIMEOUT")
    mh.removeLimitation(limitationName="STORAGE_TIME")
    mh.removeLimitation(limitationName="STORAGE_TYPE")
    mh.removeLimitation(limitationName="TASKS_ROUTER_TO_WORKER_REQUESTS_CONCURRENCY")
    mh.removeLimitation(limitationName="TASKS_TO_FACES_REQUESTS_CONCURRENCY")
    mh.removeLimitation(limitationName="TASKS_TO_HANDLERS_CONCURRENCY")
    mh.removeLimitation(limitationName="TASKS_TO_IMAGE_STORE_REQUESTS_CONCURRENCY")
    mh.removeLimitation(limitationName="USE_MATERIAL_VIEWS")
    mh.removeLimitation(limitationName="USE_SAMPLES_AS_PORTRAITS")
    mh.removeLimitation(limitationName="WORKERS_COUNT_PER_TASK_TYPE")
