"""
Configs migration

Generation datetime: 2023-04-25 16:08:07.489015
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "7f7d23cf"
DOWN_REVISION = "ce6d5386"


limitationsToModify: List[LimitationToModify] = []

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_HANDLERS_PORTRAIT_STYLE_ESTIMATOR_SETTINGS",
        validationSchema={
            "type": "object",
            "properties": {
                "runtime_settings": {
                    "type": "object",
                    "properties": {
                        "device_class": {
                            "type": "string",
                            "enum": ["global", "cpu", "gpu"],
                        },
                        "optimal_batch_size": {"type": "integer", "minimum": 1},
                        "worker_count": {"type": "integer", "minimum": 1},
                    },
                    "additionalProperties": False,
                }
            },
            "description": "settings for sdk estimator",
            "additionalProperties": False,
        },
        defaultValue={
            "runtime_settings": {
                "device_class": "global",
                "optimal_batch_size": 10,
                "worker_count": 1,
            }
        },
        description="luna-handlers settings for portrait style estimation in handlers",
        services=["luna-handlers"],
        groupNames=["luna-platform", "luna-handlers-estimators-settings"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_HANDLERS_PORTRAIT_STYLE_ESTIMATOR_SETTINGS")
