"""
Configs migration

Generation datetime: 2023-07-05 11:53:41.455867
"""

from typing import List

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "7708128b"
DOWN_REVISION = "31159b58"


def uppgradeSetting(setting: dict):
    setting["luna_handlers"] = True
    return setting


def downgradeSetting(setting: dict):
    setting.pop("luna_handlers")
    return setting


limitationsToModify: List[LimitationToModify] = [
    LimitationToModify(
        limitationName="ADDITIONAL_SERVICES_USAGE",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "luna_image_store": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "luna_matcher_proxy",
                "luna_image_store",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "luna_sender": {"type": "boolean"},
                "luna_events": {"type": "boolean"},
                "luna_tasks": {"type": "boolean"},
                "luna_matcher_proxy": {"type": "boolean"},
                "luna_image_store": {"type": "boolean"},
                "luna_handlers": {"type": "boolean"},
            },
            "required": [
                "luna_sender",
                "luna_events",
                "luna_tasks",
                "luna_matcher_proxy",
                "luna_image_store",
                "luna_handlers",
            ],
            "description": "whether to use nested optional services",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "luna_matcher_proxy": False,
            "luna_image_store": True,
        },
        newDefaultValue={
            "luna_sender": True,
            "luna_events": True,
            "luna_tasks": True,
            "luna_matcher_proxy": False,
            "luna_image_store": True,
            "luna_handlers": True,
        },
        oldDescription="whether to use nested optional services",
        newDescription="whether to use nested optional services",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=uppgradeSetting,
        settingDowngradeFunction=downgradeSetting,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
        ],
        newServices=[
            "luna-admin",
            "luna-api",
            "luna-handlers",
            "luna-matcher-proxy",
            "luna-python-matcher",
            "luna-remote-sdk",
            "luna-tasks",
        ],
    ),
]

externalLimitationsToModify: List[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to add
    mh.addLimitation(
        limitationName="LUNA_BACKPORT3_USE_HANDLERS",
        validationSchema={"type": "boolean"},
        defaultValue=True,
        description="whether to use handlers",
        services=["luna-backport3"],
        groupNames=["luna-platform"],
    )
    mh.addLimitation(
        limitationName="LUNA_REMOTE_SDK_ADDRESS",
        validationSchema={
            "type": "object",
            "properties": {
                "origin": {
                    "type": "string",
                    "pattern": "^http(s)?:\\/\\/[^\\/:]+(:\\d+)?$",
                    "example": "http://127.0.0.1:5051",
                },
                "api_version": {"type": "integer"},
            },
            "required": ["origin", "api_version"],
            "additionalProperties": False,
        },
        defaultValue={"origin": "http://127.0.0.1:5220", "api_version": 1},
        description="Address of service for remote image estimation",
        services=["luna-admin", "luna-api", "luna-handlers"],
        groupNames=["luna-platform"],
    )

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to remove
    mh.removeLimitation(limitationName="LUNA_BACKPORT3_USE_HANDLERS")
    mh.removeLimitation(limitationName="LUNA_REMOTE_SDK_ADDRESS")
