"""
Configs migration

Generation datetime: 2024-10-24 10:45:17.504079
"""

from configs_core.migration.db_migrate_helper import (
    DatabaseMigrationHelper,
    ExternalLimitationToModify,
    LimitationToModify,
)

mh: DatabaseMigrationHelper

REVISION = "5b186998"
DOWN_REVISION = "5202299a"


limitationsToModify: list[LimitationToModify] = [
    LimitationToModify(
        limitationName="LUNA_PYTHON_MATCHER_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-python-matcher service",
        newDescription="timeouts for http-request to luna-python-matcher service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=None,
        settingDowngradeFunction=None,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-lambda-unit"],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
        ],
    ),
    LimitationToModify(
        limitationName="LUNA_PYTHON_MATCHER_PROXY_TIMEOUTS",
        oldValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        newValidationSchema={
            "type": "object",
            "properties": {
                "request": {"type": "number", "exclusiveMinimum": 0},
                "connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_connect": {"type": "number", "exclusiveMinimum": 0},
                "sock_read": {"type": "number", "exclusiveMinimum": 0},
            },
            "description": "timeouts in seconds",
            "additionalProperties": False,
        },
        oldDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        newDefaultValue={
            "request": 60,
            "connect": 20,
            "sock_connect": 10,
            "sock_read": 60,
        },
        oldDescription="timeouts for http-request to luna-matcher-proxy service",
        newDescription="timeouts for http-request to luna-matcher-proxy service",
        oldGroupNames=["luna-platform"],
        newGroupNames=["luna-platform"],
        settingUpgradeFunction=None,
        settingDowngradeFunction=None,
        # DON'T REMOVE SERVICES. Used in profiled migrations.
        oldServices=["luna-api", "luna-handlers", "luna-lambda-unit"],
        newServices=[
            "luna-api",
            "luna-handlers",
            "luna-lambda-tasks-unit",
            "luna-lambda-unit",
        ],
    ),
]

externalLimitationsToModify: list[ExternalLimitationToModify] = []


def upgrade():
    """Upgrade configs to new revision"""

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)

    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)


def downgrade():
    """Downgrade configs to previous revision"""

    # limitations to modify
    for limitation in externalLimitationsToModify:
        mh.migrateLimitation(limitation)

    # limitations to modify
    for limitation in limitationsToModify:
        mh.migrateLimitation(limitation)
